@@ -25,7 +25,7 @@ setup(
 
     ext_modules = [Extension("integrate",
                              ["integrate.pyx"],
-                             libraries=['gsl','gslcblas'],
+                             libraries=cython_gsl.get_libraries(),
                              library_dirs=cython_gsl.get_library_dir(),
                              cython_include_dirs=cython_gsl.get_cython_include_dir())]
 )
